import customsprites
import display
import terrain
from helper import *

class Projectile:
	def __init__(self, target):
		self.target = target
		self.sprite.dest = display.get_screen().tile_to_screen(self.target.position)
		self.sprite.proj = self
	
	def set_position(self, t_pos):
		self.position = tup2rect(t_pos)
		self.sprite.set_location(display.get_screen().tile_to_screen(t_pos))
	
	def update(self, tick):
		self.sprite.dest = display.get_screen().tile_to_screen(self.target.position)

	def impact(self):
		display.get_map().del_projectile(self)

class Fireball(Projectile):
	def __init__(self, target, el):
		self.attack = 5
		self.sprite = customsprites.ProjectileSprite('Fireball', el)
		Projectile.__init__(self, target)
	
	def impact(self):
		if self.target.damage < self.target.vitality and self.target.damage >= 0:
			self.target.damage += self.attack
		Projectile.impact(self)

class HeighwayFireball(Projectile):
	def __init__(self, target, el, dir):
		self.attack = 5
		self.sprite = customsprites.ProjectileSprite('HFireball', el)
		if dir == customsprites.Directions.UpLeft:
			self.tweak_pos = (-30, 0)
		elif dir == customsprites.Directions.DownLeft:
			self.tweak_pos = (-30, 40)
		elif dir == customsprites.Directions.UpRight:
			self.tweak_pos = (30, 0)
		elif dir == customsprites.Directions.DownRight:
			self.tweak_pos = (30, 40)
		else:
			self.tweak_pos = (0, 0)
		
		self.sprite.speed = 12
		Projectile.__init__(self, target)
	
	def set_position(self, t_pos):
		self.position = tup2rect(t_pos)
		self.sprite.set_location(display.get_screen().tile_to_screen(t_pos).move(self.tweak_pos))
		self.tweak_pos = (0, 0)
	
	def impact(self):
		if self.target.damage < self.target.vitality and self.target.damage >= 0:
			self.target.damage += self.attack
		Projectile.impact(self)
